def Search(screen, logfilename, searchstring, case_sensitive):

    screen.write("Starting to search\n")

    searchterm = searchstring.split("%")

    inputfile = open(logfilename, "r")

    if not case_sensitive:
        # change all the searchterms to lowercase
        temp=[]
        for x in searchterm:
            temp.append(x.lower())
        searchterm=temp

    screenoutput = []
    for line in inputfile:
        searchline = line
        if not case_sensitive:
            searchline = line.lower()

        for x in searchterm:
            if searchline.find(x) >= 0:
                screenoutput.append(line)
                break
    inputfile.close()
    
    screen.write("".join(screenoutput))

    screen.write("Finished searching\n")
